package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import com.bonus.material.ma.domain.vo.MaTypeVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.TypeRepair;
import com.bonus.material.ma.service.ITypeRepairService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 维修班机具配置Controller
 *
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "维修班机具配置接口")
@RestController
@RequestMapping("/ma_type_repair")
public class TypeRepairController extends BaseController
{
    @Autowired
    private ITypeRepairService typeRepairService;

    /**
     * 查询维修班机具配置列表
     */
    @ApiOperation(value = "查询维修班机具配置列表")
    @RequiresPermissions("ma:repair:list")
    @GetMapping("/list")
    public TableDataInfo list(TypeRepair typeRepair)
    {
        startPage();
        List<TypeRepair> list = typeRepairService.selectTypeRepairList(typeRepair);
        return getDataTable(list);
    }

    /**
     * 查询维修班机具配置下拉列表
     * @param typeRepair
     * @return
     */
    @ApiOperation(value = "查询维修班机具配置下拉")
    //@RequiresPermissions("ma:repair:list")
    @GetMapping("/getRepairList")
    public AjaxResult getRepairList(TypeRepair typeRepair)
    {
        return typeRepairService.getRepairList(typeRepair);
    }

    /**
     * 导出维修班机具配置列表
     */
    @ApiOperation(value = "导出维修班机具配置列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:repair:export")
    @SysLog(title = "维修班机具配置", businessType = OperaType.EXPORT, module = "仓储管理->导出维修班机具配置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TypeRepair typeRepair)
    {
        List<TypeRepair> list = typeRepairService.selectTypeRepairList(typeRepair);
        ExcelUtil<TypeRepair> util = new ExcelUtil<TypeRepair>(TypeRepair.class);
        util.exportExcel(response, list, "维修班机具配置数据");
    }

    /**
     * 获取维修班机具配置详细信息
     */
    @ApiOperation(value = "获取维修班机具配置详细信息")
    @RequiresPermissions("ma:repair:query")
    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") Long ID)
    {
        return success(typeRepairService.selectTypeRepairByID(ID));
    }

    /**
     * 新增维修班机具配置
     */
    @ApiOperation(value = "新增维修班机具配置")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:repair:add")
    @SysLog(title = "维修班机具配置", businessType = OperaType.INSERT, module = "仓储管理->新增维修班机具配置")
    @PostMapping
    public AjaxResult add(@RequestBody List<TypeRepair> typeRepairs)
    {
        return toAjax(typeRepairService.insertTypeRepair(typeRepairs));
    }

    /**
     * 修改维修班机具配置
     */
    @ApiOperation(value = "修改维修班机具配置")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:repair:edit")
    @SysLog(title = "维修班机具配置", businessType = OperaType.UPDATE, module = "仓储管理->修改维修班机具配置")
    @PutMapping
    public AjaxResult edit(@RequestBody TypeRepair typeRepair)
    {
        return toAjax(typeRepairService.updateTypeRepair(typeRepair));
    }

    /**
     * 批量删除维修班机具配置
     */
    @ApiOperation(value = "批量删除维修班机具配置")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:repair:remove")
    @SysLog(title = "维修班机具配置", businessType = OperaType.DELETE, module = "仓储管理->批量删除维修班机具配置")
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(typeRepairService.deleteTypeRepairByIDs(IDs));
    }

    /**
     * 删除单个维修班机具配置
     */
    @ApiOperation(value = "删除单个维修班机具配置")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:repair:remove")
    @SysLog(title = "维修班机具配置", businessType = OperaType.DELETE, module = "仓储管理->删除单个维修班机具配置")
    @PostMapping("/unbind")
    public AjaxResult remove(@RequestBody List<TypeRepair> typeRepairs)
    {
        return toAjax(typeRepairService.deleteTypeRepairByUserIdAndTypeId(typeRepairs));
    }

    /**
     * 新增人员配置
     */
    @ApiOperation(value = "新增人员配置")
    @PreventRepeatSubmit
    @SysLog(title = "新增人员配置", businessType = OperaType.INSERT, module = "仓储管理->新增人员配置")
    @PostMapping("/addTypeManage")
    public AjaxResult addTypeManage(@RequestBody List<TypeRepair> typeRepairs)
    {
        return toAjax(typeRepairService.addTypeManage(typeRepairs));
    }

    /**
     * 查询人员配置列表
     */
    @ApiOperation(value = "查询人员配置列表")
    @GetMapping("/getTypeManageList")
    public TableDataInfo getTypeManageList(MaTypeVo maTypeVo)
    {
        startPage();
        List<MaTypeVo> list = typeRepairService.getTypeManageList(maTypeVo);
        return getDataTable(list);
    }

    /**
     * 删除维修班机具配置
     */
    @ApiOperation(value = "删除单个维修班机具配置")
    @PreventRepeatSubmit
    @SysLog(title = "维修班机具配置", businessType = OperaType.DELETE, module = "仓储管理->删除单个维修班机具配置")
    @PostMapping("/unbindTypeManage")
    public AjaxResult unbindTypeManage(@RequestBody List<TypeRepair> typeRepairs)
    {
        return toAjax(typeRepairService.deleteTypeManageByUserIdAndTypeId(typeRepairs));
    }
}
